re_num_list = [
    "\d{1,7}",
    "\d{1,7}[\.,-]\d{1,7}",
    "\d{1,3}[\.,]\d{3}[\.,]\d{1,5}",
    "\d{1,3}[\.,]\d{3}[\.,]\d{1,3}[\.,]\d{1,5}",
]